<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/LeadBundle/Translations/en_US/messages.ini */
class __TwigTemplate_ec1740c4d522ec0d92bc34b72802e40b extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "mautic.campaign.lead.changelist=\"Modify contact's segments\"
mautic.campaign.lead.changepoints=\"Adjust contact points\"
mautic.campaign.lead.changetags=\"Change tags\"
mautic.campaign.lead.adddnc=\"Add Do Not Contact\"
mautic.campaign.lead.removednc=\"Remove Do Not Contact\"
mautic.campaign.lead.field_value=\"Contact field value\"
mautic.campaign.lead.device=\"Contact device\"
mautic.campaign.lead.owner=\"Contact owner\"
mautic.campaign.lead.updatelead=\"Update contact\"
mautic.campaign.lead.updatecompany=\"Update contact's primary company\"
mautic.contact.error.notfound=\"Contact not found.\"
mautic.contact.noinformation.devices=\"Everyone's eager to learn what gadgets your customers love. Make sure our tracking script is part of your website.\"
mautic.contact.noinformation.places=\"Our system is still on the trail. Don’t forget to enable geolocation services in the settings.\"
mautic.contact.noinformation.statistics=\"Zero email activity? Fill them up by sending some emails.\"
mautic.contact.noinformation.upcoming=\"Add your lead to a segment or campaign to see upcoming activities.\"
mautic.campaign.lead.scorecontactscompanies=\"Score company\"
mautic.campaign.lead.deletecontact=\"Delete contact\"
mautic.campaign.lead.notfound=\"No marketing campaigns yet. Consider adding to one.\"
mautic.campaign.lead.segments=\"Segments\"
mautic.campaign.lead.tags=\"Tags\"
mautic.campaign.lead.points=\"Contact points\"
mautic.protip.contacts.view=\"Use the <kbd>V</kbd> key to switch between card and table views.\"
mautic.protip.contacts.tags=\"Add tags during import to help organize and segment your contacts. Example: (import_facebook_may2024)\"
mautic.protip.contacts.list=\"Build your email list through organic opt-ins rather than purchasing lists.\"
mautic.protip.segments.dynamic=\"Use behavioral data like website activity and email engagement to create dynamic segments that update automatically\"
mautic.protip.segments.test=\"Test different segment combinations to find the most effective groupings for your campaigns\"
mautic.core.date.added_first=\"First Touch Date Added\"
mautic.core.date.added_last=\"Last Touch Date Added\"
mautic.contact.import.tip.title=\"Want to add more than one contact at once?\"
mautic.contact.import.tip.description=\"Save time and use our import contacts tool.\"
mautic.contact.import.tip.button=\"Import multiple contacts\"
mautic.placeholder_tokens.contact.tokens=\"Emails, Text Messages and Dynamic Content\"
mautic.placeholder_tokens.contact_fields=\"Contact\"
mautic.placeholder_tokens.contact_owner_fields=\"Contact owner\"
mautic.placeholder_tokens.company_contact_fields=\"Company\"
mautic.placeholder_tokens.custom_fields=\"Custom fields\"
mautic.placeholder_tokens.contact.attribution=\"Attribution\"
mautic.placeholder_tokens.contact.attribution_date=\"Attribution Date\"
mautic.placeholder_tokens.contact.address1=\"Address Line 1\"
mautic.placeholder_tokens.contact.address2=\"Address Line 2\"
mautic.placeholder_tokens.contact.country=\"Country\"
mautic.placeholder_tokens.contact.city=\"City\"
mautic.placeholder_tokens.contact.company=\"Company\"
mautic.placeholder_tokens.contact.id=\"Contact ID\"
mautic.placeholder_tokens.contact.email=\"Email\"
mautic.placeholder_tokens.contact.facebook=\"Facebook\"
mautic.placeholder_tokens.contact.fax=\"Fax\"
mautic.placeholder_tokens.contact.firstname=\"First Name\"
mautic.placeholder_tokens.contact.foursquare=\"Foursquare\"
mautic.placeholder_tokens.contact.googleplus=\"Google+\"
mautic.placeholder_tokens.contact.instagram=\"Instagram\"
mautic.placeholder_tokens.contact.ipaddress=\"IP Address\"
mautic.placeholder_tokens.contact.lastname=\"Last Name\"
mautic.placeholder_tokens.contact.linkedin=\"LinkedIn\"
mautic.placeholder_tokens.contact.mobile=\"Mobile Number\"
mautic.placeholder_tokens.contact.phone=\"Phone Number\"
mautic.placeholder_tokens.contact.position=\"Position\"
mautic.placeholder_tokens.contact.skype=\"Skype\"
mautic.placeholder_tokens.contact.state=\"State\"
mautic.placeholder_tokens.contact.twitter=\"Twitter\"
mautic.placeholder_tokens.contact.title=\"Title\"
mautic.placeholder_tokens.contact.website=\"Website\"
mautic.placeholder_tokens.contact.zipcode=\"Zip Code\"
mautic.placeholder_tokens.owner.firstname=\"First Name\"
mautic.placeholder_tokens.owner.lastname=\"Last Name\"
mautic.placeholder_tokens.owner.email=\"Email\"
mautic.placeholder_tokens.owner.position=\"Position\"
mautic.placeholder_tokens.owner.signature=\"Signature\"
mautic.placeholder_tokens.company.address1=\"Address Line 1 (Company)\"
mautic.placeholder_tokens.company.address2=\"Address Line 2 (Company)\"
mautic.placeholder_tokens.company.annual_revenue=\"Annual Revenue (Company)\"
mautic.placeholder_tokens.company.city=\"City (Company)\"
mautic.placeholder_tokens.company.country=\"Country (Company)\"
mautic.placeholder_tokens.company.description=\"Description (Company)\"
mautic.placeholder_tokens.company.email=\"Email (Company)\"
mautic.placeholder_tokens.company.fax=\"Fax (Company)\"
mautic.placeholder_tokens.company.industry=\"Industry (Company)\"
mautic.placeholder_tokens.company.name=\"Name\"
mautic.placeholder_tokens.company.number_of_employees=\"Number of Employees (Company)\"
mautic.placeholder_tokens.company.phone=\"Phone Number (Company)\"
mautic.placeholder_tokens.company.state=\"State (Company)\"
mautic.placeholder_tokens.company.website=\"Website (Company)\"
mautic.placeholder_tokens.company.zipcode=\"Zip Code (Company)\"
mautic.placeholder_tokens.custom_fields.date_and_time=\"Date and Time\"
mautic.placeholder_tokens.custom_fields.date_and_time.description=\"When working with date and time fields, you can specify date and time formats based on your Mautic's settings.\"
mautic.placeholder_tokens.custom_fields.datetime=\"Date and Time\"
mautic.placeholder_tokens.custom_fields.date=\"Date only\"
mautic.placeholder_tokens.custom_fields.time=\"Time only\"
mautic.placeholder_tokens.custom_fields.note=\"Replace aliasofyourcustomdatefield with the alias of your custom field.\"
mautic.email.batch.categories=\"Change Category\"
mautic.email.category.batch.set=\"Change to Category\"
mautic.lead.lead.searchcommand.isanonymous.description=\"Filters for contacts that are anonymous (not identified)\"
mautic.lead.lead.searchcommand.isunowned.description=\"Filters for contacts that are not assigned to any user\"
mautic.lead.lead.searchcommand.list.description=\"Filters contacts by a specific segment (use the segment alias)\"
mautic.lead.lead.searchcommand.company.description=\"Filters contacts by company name\"
mautic.lead.lead.searchcommand.company_id.description=\"Filters contacts by company ID\"
mautic.lead.lead.searchcommand.owner.description=\"Filters for contacts owned by a specific user\"
mautic.lead.lead.searchcommand.tag.description=\"Filters contacts by a specific tag\"
mautic.lead.lead.searchcommand.stage.description=\"Filters contacts by a specific stage\"
mautic.lead.lead.searchcommand.duplicate.description=\"Finds contacts that are common among the specified segments\"
mautic.lead.lead.searchcommand.email_sent.description=\"Filters contacts who have been sent a specific email\"
mautic.lead.lead.searchcommand.email_read.description=\"Filters contacts who have read a specific email\"
mautic.lead.lead.searchcommand.email_queued.description=\"Filters contacts who have a specific email queued to be sent\"
mautic.lead.lead.searchcommand.email_pending.description=\"Filters contacts who have a specific email pending\"
mautic.lead.lead.searchcommand.page_source.description=\"Filters contacts by the source of the page they visited\"
mautic.lead.lead.searchcommand.page_source_id.description=\"Filters contacts by the ID of the page source\"
mautic.lead.lead.searchcommand.import_id.description=\"Filters contacts by a specific import ID\"
mautic.lead.lead.searchcommand.import_action.description=\"Filters contacts by a specific import action\"
mautic.lead.lead.searchcommand.page_id.description=\"Filters contacts who have visited a specific page (by ID)\"
mautic.lead.lead.searchcommand.sms_sent.description=\"Filters contacts who have been sent a specific SMS\"
mautic.lead.lead.searchcommand.web_sent.description=\"Filters contacts who have been sent a specific web notification\"
mautic.lead.lead.searchcommand.mobile_sent.description=\"Filters contacts who have been sent a specific mobile notification\"
title.description=\"Searches contacts by their title\"
firstname.description=\"Searches contacts by their first name\"
lastname.description=\"Searches contacts by their last name\"
company.description=\"Searches contacts by their company name\"
position.description=\"Searches contacts by their job position\"
email.description=\"Searches notes for contacts by email address\"
mobile.description=\"Searches contacts by their mobile phone number\"
phone.description=\"Searches contacts by their phone number\"
points.description=\"Searches contacts by their point total\"
fax.description=\"Searches contacts by their fax number\"
address1.description=\"Searches contacts by their primary address\"
address2.description=\"Searches contacts by their secondary address\"
city.description=\"Searches contacts by their city\"
state.description=\"Searches contacts by their state or province\"
zipcode.description=\"Searches contacts by their zip or postal code\"
country.description=\"Searches contacts by their country\"
preferred_locale.description=\"Searches contacts by their preferred language/locale\"
timezone.description=\"Searches contacts by their timezone\"
last_active.description=\"Searches contacts by their last active date\"
attribution_date.description=\"Searches contacts by their attribution date\"
attribution.description=\"Searches contacts by their attribution value\"
website.description=\"Searches contacts by their website URL\"
facebook.description=\"Searches contacts by their Facebook profile\"
foursquare.description=\"Searches contacts by their Foursquare profile\"
instagram.description=\"Searches contacts by their Instagram profile\"
linkedin.description=\"Searches contacts by their LinkedIn profile\"
skype.description=\"Searches contacts by their Skype username\"
twitter.description=\"Searches contacts by their Twitter handle\"
mautic.lead.add.note=\"Add note\"
mautic.lead.attribution=\"Attribution\"
mautic.lead.attribution.tooltip=\"Specify the estimated revenue this lead has generated across all marketing touchpoints.\"
mautic.lead.attribution_date=\"Attribution date\"
mautic.lead.attribution_date.tooltip=\"Select the date when the attributed revenue was realized or should be credited.\"
mautic.lead.batch.add_to=\"Add to the following:\"
mautic.lead.batch.campaigns=\"Change Campaigns\"
mautic.lead.batch.owner=\"Change Owner\"
mautic.lead.batch.categories=\"Change Categories\"
mautic.lead.batch.channels=\"Change Channels\"
mautic.lead.batch.dnc=\"Set Do Not Contact\"
mautic.lead.batch.dnc_reason=\"Reason\"
mautic.lead.batch.lists=\"Change Segments\"
mautic.lead.batch.remove_from=\"Remove from the following:\"
mautic.lead.batch.stages=\"Change Stages\"
mautic.lead.no_company=\"This contact is not associated with a company.\"
mautic.lead.contact=\"Contact\"
mautic.lead.contact.channels=\"Channels\"
mautic.lead.contact.frequency=\"Preferences\"
mautic.lead.lead.field.stage=\"Stage\"
mautic.lead.device=\"Device\"
mautic.lead.device.header=\"Type\"
mautic.lead.devices=\"Devices\"
mautic.lead.device_brand=\"Device brand\"
mautic.lead.device_brand.header=\"Brand\"
mautic.lead.device_browser.header=\"Browser\"
mautic.lead.device_model=\"Device model\"
mautic.lead.device_os_name=\"Device OS\"
mautic.lead.device_os_name.header=\"Operating System\"
mautic.lead.device_os_shortname=\"Device OS shortname\"
mautic.lead.device_os_version=\"Device OS version\"
mautic.lead.device_os_version.header=\"OS Version\"
mautic.lead.device_os_platform=\"Device OS platform\"
mautic.lead.do.not.contact=\"Do Not Contact\"
mautic.lead.do.not.contact_bounced=\"Bounced\"
mautic.lead.do.not.contact_unsubscribed=\"Unsubscribed\"
mautic.lead.do.not.contact_manual=\"Manual\"
mautic.lead.do.not.contact_channel=\"Do Not Contact: %channel%\"
mautic.lead.do.not.contact_bounced_channel=\"Bounced: %channel%\"
mautic.lead.email.from_email=\"From\"
mautic.lead.email.from_name=\"From address\"
mautic.lead.email.header.index=\"Contact Fields\"
mautic.lead.email.send_email=\"Send email\"
mautic.lead.email.send_email.header=\"Send a custom email to %email%\"
mautic.lead.email.send_email.disabled=\"Contact does not have an email address, thus email sending is disabled.\"
mautic.lead.email.template=\"Import from an existing template\"
mautic.lead.event.delete=\"Contact deleted\"
mautic.lead.event.merge=\"Contact merged\"
mautic.lead.event.create=\"Contact created\"
mautic.lead.event.donotcontact=\"Do not contact\"
mautic.lead.event.donotcontact_channel=\"Do not contact: %channel%\";
mautic.lead.event.donotcontact_contactable=\"Contact is contactable.\"
mautic.lead.event.donotcontact_bounced=\"Communication bounced for this channel.\"
mautic.lead.event.donotcontact_manual=\"Contact was manually set as do not contact for this channel.\"
mautic.lead.event.donotcontact_unsubscribed=\"Contact unsubscribed from this channel.\"
mautic.lead.event.identified=\"Contact identified\"
mautic.lead.event.ipadded=\"Accessed from IP\"
mautic.lead.event.update=\"Contact updated\"
mautic.lead.event.utmtagsadded=\"UTM tags recorded\"
mautic.lead.field.indexable=\"Indexable\"
mautic.lead.field.tags=\"Tags\"
mautic.lead.field.timezone=\"Preferred Timezone\"
mautic.lead.field.address=\"Address\"
mautic.lead.field.utmcampaign=\"Campaign\"
mautic.lead.field.utmcontent=\"Content\"
mautic.lead.field.utmmedium=\"Medium\"
mautic.lead.field.umtsource=\"Source\"
mautic.lead.field.utmterm=\"Term\"
mautic.lead.event.api=\"API\"
mautic.lead.event.api.operation.not.allowed=\"The requested operation is not permitted.\"
mautic.lead.event.api.lead.not.found=\"Contact could not be found.\"
mautic.lead.event.api.point.group.not.found=\"The specified point group was not found.\"
mautic.lead.event.apiadded=\"Added through API\"
mautic.lead.field.form.choose=\"Select a field\"
mautic.lead.field.form.confirmbatchdelete=\"Delete the selected custom fields? WARNING: this will also delete any values of these custom fields that are associated with contacts.\"
mautic.lead.field.form.confirmdelete=\"Delete the custom field, %name%? WARNING: this will also delete any values of this custom field that are associated with contacts.\"
mautic.lead.field.form.group.help=\"Determines where this field will be displayed when viewing a specific contact.\"
mautic.lead.field.form.islistable=\"Available for segments\"
mautic.lead.field.form.isshortvisible=\"Visible on quick add\"
mautic.lead.field.form.isshortvisible.tooltip=\"If set to yes, this field will be displayed in the quick add contact modal\"
mautic.lead.field.form.isuniqueidentifer=\"Is Unique Identifier\"
mautic.lead.field.form.isuniqueidentifer.tooltip=\"Set if this field will be the main way to differentiate contacts (i.e. email, username, social media handle, etc).\"
mautic.lead.field.form.isuniqueidentifer.warning=\"WARNING: Inappropriately setting &quot;Is Unique Identifier&quot; to Yes could cause a mass merging of contacts and incorrectly tracked contact activity. Only set to Yes if this field tracks a unique value specific to the contact such as email, username, etc.\"
mautic.lead.field.form.isvisible=\"Visible on forms\"
mautic.lead.field.form.ispubliclyupdatable=\"Publicly updatable\"
mautic.lead.field.form.ispubliclyupdatable.tooltip=\"If set to yes, this field can be updated by appending the field's alias and value to the query of the /mtracking.gif tracking pixel.\"
mautic.lead.field.form.maximum.character.length=\"Maximum character length\"
mautic.lead.field.form.number.rounddown=\"Round Down\"
mautic.lead.field.form.number.roundhalfdown=\"Round Half Down\"
mautic.lead.field.form.number.roundhalfeven=\"Round Half Even\"
mautic.lead.field.form.number.roundhalfup=\"Round Half Up\"
mautic.lead.field.form.number.roundup=\"Round Up\"
mautic.lead.field.form.properties.boolean=\"Boolean Labels\"
mautic.lead.field.form.properties.lookup=\"Lookup values\"
mautic.lead.field.form.properties.numberprecision=\"Precision\"
mautic.lead.field.form.properties.numberrounding=\"Rounding mode\"
mautic.lead.field.form.properties.select=\"Options\"
mautic.lead.field.form.isIndex.tooltip=\"Making this field indexable may improve search performance. %indexCount% indexes out of %maxCount% have been used.\"
mautic.lead.field.indexable.yes=\"Enable faster searches\"
mautic.lead.field.indexable.no=\"Standard search speed\"
mautic.lead.field.searchcommand.isindexed=\"is:indexed\"
mautic.lead.field.searchcommand.isunique=\"is:unique\"
mautic.lead.field.searchcommand.type=\"type\"
mautic.lead.field.searchcommand.group=\"group\"
mautic.lead.lead.update.action.help=\"Update the contact fields with values from this event.\"
mautic.lead.company.update.action.help=\"Update the company fields with values from this event.\"
mautic.lead.field.group=\"Group\"
mautic.lead.field.group.core=\"Core\"
mautic.lead.field.group.company=\"Company\"
mautic.lead.field.group.extra=\"Extra\"
mautic.lead.field.group.personal=\"Personal\"
mautic.lead.field.group.professional=\"Professional\"
mautic.lead.field.group.social=\"Social\"
mautic.lead.field.group.no_data=\"No data\"
mautic.lead.field.header.contact=\"Contact\"
mautic.lead.field.header.edit=\"Edit Custom Field - %name%\"
mautic.lead.field.header.engagements=\"Engagements\"
mautic.lead.field.header.index=\"Custom Fields\"
mautic.lead.field.header.new=\"New Custom Field\"
mautic.lead.field.help.alias=\"Letters and numbers (with no spaces) used to identify this field. A unique alias will be autogenerated if left empty.\"
mautic.lead.field.help.lookup=\"Also known as a typeahead. Leave blank to load unique existing values from the database or insert a specific segment. Separate options using a vertical bar ( | ). I.e. Red|Green|Blue\"
mautic.lead.field.help.numberprecision=\"Number of decimal allowed before rounding occurs.\"
mautic.lead.field.help.numberrounding=\"Round down - round towards zero.<br />Round up - round away from zero.<br />Round half down - round towards the nearest neighbor. If both are equidistant (equal distances), round down.<br />Round half even - round towards the nearest neighbor. If both are equidistant, round towards the even neighbor.<br />Round half up - round towards the nearest neighbor. If both are equidistant, round up.\"
mautic.lead.field.help.select=\"Insert the desired options using a vertical bar ( | ) to separate them. I.e. Red|Green|Blue\"
mautic.lead.field.help.defaultvalue=\"A default value will only apply to new contacts. It will not update existing contacts. On a custom field, it only applies to new contacts being added, not historical ones\"
mautic.lead.field.menu.index=\"Custom Fields\"
mautic.lead.field.label=\"Label\"
mautic.lead.field.linkedin=\"LinkedIn\"
mautic.lead.field.tooltip.fixed=\"Cannot be removed (used internally).\"
mautic.lead.field.tooltip.invisible=\"Does not show in contact forms.\"
mautic.lead.field.tooltip.listable=\"Can be used as a segment filter.\"
mautic.lead.field.tooltip.required=\"Is required when filling in contact forms.\"
mautic.lead.field.tooltip.public=\"Can be publicly updated via the query of the tracking pixel URL.\"
mautic.lead.field.tooltip.isuniqueidentifer=\"Is Unique Identifier\"
mautic.lead.field.tooltip.isindex=\"Is indexed and faster search results are provided\"
mautic.lead.field.type=\"Data Type\"
mautic.lead.field.type.datetime=\"Date/Time\"
mautic.lead.field.type.locale=\"Locale\"
mautic.lead.field.type.html=\"HTML\"
mautic.lead.field.type.lookup=\"Lookup\"
mautic.lead.field.type.multiselect=\"Select: Multiple choices\"
mautic.lead.field.type.region=\"Region\"
mautic.lead.field.type.tel.home=\"Phone - home\"
mautic.lead.field.type.tel.mobile=\"Phone - mobile\"
mautic.lead.field.type.textarea=\"Text: Paragraph\"
mautic.lead.field.type.time=\"Time\"
mautic.lead.field.type.timezone=\"Timezone\"
mautic.lead.graph.line.leads=\"New contacts added\"
mautic.lead.graph.line.leads.emails=\"New contacts with email address\"
mautic.lead.graph.line.leads.leads=\"All new contacts\"
mautic.lead.graph.line.points=\"Points\"
mautic.lead.graph.line.all_engagements=\"Engagements\"
mautic.lead.graph.pie.attribution_campaigns=\"Total attributions by campaigns\"
mautic.lead.graph.pie.attribution_stages=\"Total attributions by stages\"
mautic.lead.graph.pie.attribution_actions=\"Total attributions by actions\"
mautic.lead.graph.pie.attribution_channels=\"Total attributions by channels\"
mautic.lead.grid.noresults.header=\"No Contacts Found\"
mautic.lead.grid.noresults.message=\"Seems there are none, or you do not have the necessary permissions. If applicable, change a filter or contact your administrator.\"
mautic.lead.import=\"Import\"
mautic.lead.import.batchlimit=\"Limit\"
mautic.lead.import.batchlimit_tooltip=\"Sets the number of contacts to import per batch.\"
mautic.lead.import.delimiter=\"Delimiter\"
mautic.lead.import.delimiter.help=\"It’s the character that separates each piece of data in your file, often a comma (,).\"
mautic.lead.import.enclosure=\"Enclosure\"
mautic.lead.import.enclosure.help=\"It’s a character that holds each piece of data in your file, often a quote (&#x22;).\"
mautic.lead.import.error.header_mismatch=\"The number of data columns is more than the number of header columns (the first row)\"
mautic.lead.import.error.line_empty=\"No data found\"
mautic.lead.import.escape=\"Escape\"
mautic.lead.import.escape.help=\"It’s a character that lets you use special characters without confusing the system, often a backslash (\\).\"
mautic.lead.import.file=\"Upload CSV file\"
mautic.lead.import.inprogress=\"Import is in progress.\"
mautic.lead.import.completed=\"Import completed\"
mautic.lead.import.result.info=\"View details of %import%\"
mautic.lead.import.ghost.limit.hit=\"The import hasn't been updated in %limit% hours by the background job. It's considered failed.\"
mautic.lead.import.default.owner=\"(Optional) Set the owner and the contact segment for the imported contacts.\"
mautic.lead.import.donotleave=\"Please do not leave this page until complete or queued.\"
mautic.lead.import.mapped.fields=\"Mapped fields\"
mautic.lead.import.default.options=\"Default options\"
mautic.lead.import.csv.headers=\"CSV headers\"
mautic.lead.import.csv.parser.config=\"CSV parser config\"
mautic.lead.import.fields=\"Match the columns from the imported file to Mautic's contact fields.\"
mautic.lead.special_fields=\"Properties\"
mautic.lead.import.leads=\"Import %object%\"
mautic.lead.import.skip_if_exists=\"Keep value if already exists\"
mautic.lead.import.in.background=\"Import in background\"
mautic.lead.import.delayed=\"Import has been delayed: %reason%\"
mautic.lead.import.start=\"Import in browser\"
mautic.lead.import.start.instructions=\"Upload the CSV file containing the contacts to import. A maximum of %size%MB can be uploaded. The next step will be to match the fields in the file with the fields available in Mautic.\"
mautic.lead.import.label.stage=\"Stage\"
mautic.lead.import.label.ownerusername=\"Owner by username\"
mautic.lead.import.label.tags=\"Tags\"
mautic.lead.import.stats=\"%created% created, %merged% merged, %ignored% ignored\"
mautic.lead.import.success=\"Success!\"
mautic.lead.import.upload=\"Upload\"
mautic.lead.import.event.name=\"Contact Import\"
mautic.lead.import.action.name=\"By %name%\"
mautic.lead.import.by.user=\"Imported by %user%\"
mautic.lead.import.label.id=\"ID\"
mautic.lead.import.label.createdByUser=\"Created by user\"
mautic.lead.import.label.dateAdded=\"Date created\"
mautic.lead.import.label.dateIdentified=\"Identified date\"
mautic.lead.import.label.dateModified=\"Modified date\"
mautic.lead.import.label.doNotEmail=\"Do not contact\"
mautic.lead.import.label.ip=\"IP\"
mautic.lead.import.label.lastActive=\"Last active date\"
mautic.lead.import.label.modifiedByUser=\"Modified by user\"
mautic.lead.import.label.points=\"Points\"
mautic.lead.import.is.starting=\"Import %id% with %lines% rows is starting.\"
mautic.lead.import.result=\"%lines% lines were processed, %created% items created, %updated% items updated, %ignored% items ignored in %time% s\"
mautic.lead.import.failed=\"Import failed. Reason: %reason%\"
mautic.lead.background.import.if.more.rows.than=\"Automatically import in the background if the CSV has more rows than defined\"
mautic.lead.background.import.if.more.rows.than.tooltip=\"If this option is greater than 0, there will be only one Import button and the browser/background import will be decided based on the CSV row number\"
mautic.lead.background.export.csv=\"Export contacts in the background in CSV\"
mautic.lead.background.export.csv.tooltip=\"If this is Yes, then contacts will exported in background for CSV only\"
mautic.lead.behaviors=\"Contact Behavior and Actions\"
mautic.lead.groups=\"Contact group points\"
mautic.config.tab.leadconfig=\"Contact Settings\"
mautic.config.tab.companyconfig=\"Company Settings\"
mautic.config.tab.importconfig=\"Import Settings\"
mautic.config.tab.contact.list.settings=\"Contact List Settings\"
mautic.config.tab.exportconfig=\"Export Settings\"
mautic.config.tab.columns=\"Columns\"
mautic.config.tab.contact.merge.settings=\"Contact Merge Settings\"
mautic.config.tab.company.merge.settings=\"Company Merge Settings\"
mautic.core.config.unique_identifiers_operator=\"Merge by unique fields with operator\"
mautic.core.config.unique_identifiers_operator.tooltip=\"If you use more than one unique field identifier then you can define the way of the find to merge it. \"
mautic.core.config.allow_multiple_companies=\"Multiple companies for contact\"
mautic.core.config.allow_multiple_companies.tooltip=\"Enable assigning multiple companies to contact. No = contact can be assigned to only 1 company. Assigning a new company to that contact will replace the previously assigned company. Yes = contact can have multiple companies assigned. The latest assigned company is the primary company.\"
mautic.core.config.contact_unique_identifiers_operator.or=\"OR\"
mautic.core.config.contact_unique_identifiers_operator.and=\"AND\"
mautic.config.tab.segment_config=\"Segment Settings\"
mautic.lead.import.unique_field_not_exist=\"No unique fields exist in the import\"
mautic.lead.import.database.exception=\"There was a database error: %message%. The import was set to delayed state and will be imported later.\"
mautic.lead.lastactive=\"Last active\"
mautic.lead.lead.anonymous=\"Anonymous\"
mautic.lead.lead.anonymous_leads=\"Toggle anonymous contacts\"
mautic.lead.lead.event.points=\"Points (+/-)\"
mautic.lead.lead.event.pointtrigger=\"Minimum number of points\"
mautic.lead.lead.event.grouppoints=\"Points (%group%)\"
mautic.lead.lead.events.addtolists=\"Add contact to selected segment(s)\"
mautic.lead.lead.events.addutmtags=\"Record UTM Tags\"
mautic.lead.lead.events.addutmtags_descr=\"Universal Tags will be recorded on the contact's profile\"
mautic.lead.lead.events.removedonotcontact=\"Remove contact from do not contact list\"
mautic.lead.lead.events.removedonotcontact_descr=\"Contact will be re-subscribed\"
mautic.lead.lead.events.changelist=\"Modify contact's segments\"
mautic.lead.lead.events.changelist_descr=\"Add contact to or remove contact from segment(s)\"
mautic.lead.lead.events.changepoints=\"Adjust contact points\"
mautic.lead.lead.events.changepoints_descr=\"Increase or decrease points\"
mautic.lead.lead.events.changestage=\"Change contact's stage\"
mautic.lead.lead.events.changestage_descr=\"Change a contact's stage when the selected action occurs\"
mautic.lead.lead.events.changetags=\"Modify contact's tags\"
mautic.lead.lead.events.changetags_descr=\"Add tag to or remove tag from contact\"
mautic.lead.lead.events.leadcreated=\"contact created\"
mautic.lead.lead.events.leadcreated_descr=\"Trigger event upon a new contact being created\"
mautic.lead.lead.events.listchange=\"contact changed segments\"
mautic.lead.lead.events.listchange_descr=\"Trigger event upon a contact changing segments\"
mautic.lead.lead.events.listtrigger.added=\"Added to segment\"
mautic.lead.lead.events.listtrigger.removed=\"Removed from segment\"
mautic.lead.lead.events.pointchange=\"contact points changed\"
mautic.lead.lead.events.pointchange_descr=\"Trigger event upon a contact's point total being changed\"
mautic.lead.lead.events.removefromlists=\"Remove contact from selected segment(s)\"
mautic.lead.lead.events.updatelead=\"Update contact\"
mautic.lead.lead.events.updatelead_descr=\"Update the current contact's fields with the defined values from this action\"
mautic.lead.lead.events.updatecompany=\"Update contact's primary company\"
mautic.lead.lead.events.updatecompany_descr=\"Update the contact's primary company fields with the defined values from this action\"
mautic.lead.lead.events.delete=\"Delete contact\"
mautic.lead.lead.events.delete_descr=\"<span class='text-danger'>Permanently deletes the contact as well as all associated statistical data. <strong>Warning: this is irreversible!</strong></span>\"
mautic.lead.lead.events.add_donotcontact=\"Add Do Not Contact\"
mautic.lead.lead.events.add_donotcontact_desc=\"Add DoNotContact flag to the contact\"
mautic.lead.lead.events.remove_donotcontact=\"Remove Do Not Contact\"
mautic.lead.lead.events.remove_donotcontact_desc=\"Remove Do Not Contact flag from contact\"
mautic.lead.lead.events.field_value=\"Contact field value\"
mautic.lead.lead.events.field_value_descr=\"Condition based on a contact field value.\"
mautic.lead.lead.events.device=\"Contact device\"
mautic.lead.lead.events.device_descr=\"Condition based on a contact device.\"
mautic.lead.lead.events.pageHit=\"Visited page\"
mautic.lead.lead.events.pageHit_descr=\"Condition based on all the pages the contact has visited in the past\"
mautic.lead.lead.events.tags=\"Contact tags\"
mautic.lead.lead.events.tags_descr=\"Condition based on a contact tags.\"
mautic.lead.lead.events.segments=\"Contact segments\"
mautic.lead.lead.events.segments_descr=\"Condition based on a contact segments.\"
mautic.lead.lead.events.stages=\"Contact stages\"
mautic.lead.lead.events.stages_descr=\"Condition that the contact belongs to at least one of the selected stages.\"
mautic.lead.lead.events.points=\"Contact points\"
mautic.lead.lead.events.points_descr=\"Condition based on contact score\"
mautic.lead.segment.dependencies=\"Segment Dependencies\"
mautic.lead.lead.events.campaigns=\"Contact campaigns\"
mautic.lead.lead.events.campaigns.membership=\"Campaigns membership\"
mautic.lead.lead.events.campaigns_descr=\"Condition based on a contact campaigns.\"
mautic.lead.lead.events.campaigns.date.added.filter=\"Filter by date added to campaign\"
mautic.lead.lead.events.campaigns.expression=\"Expression\"
mautic.lead.lead.events.campaigns.date=\"Date\"
mautic.lead.lead.events.owner=\"Contact owner\"
mautic.lead.lead.events.owner_descr=\"Condition based on a contact owner.\"
mautic.lead.lead.field.custom_avatar=\"Custom\"
mautic.lead.lead.events.condition_donotcontact=\"Marked as DNC\"
mautic.lead.lead.events.condition_donotcontact_descr=\"Condition checks if the contact has the Do Not Contact flag.\"
mautic.lead.lead.field.owner=\"Contact owner\"
mautic.lead.lead.field.list=\"Contact Segment\"
mautic.lead.lead.field.preferred_profile=\"Preferred profile image\"
mautic.lead.lead.filter.bundles.exclude.placeholder=\"Exclude events by source\"
mautic.lead.lead.filter.bundles.include.placeholder=\"Include events by source\"
mautic.lead.lead.form.confirmbatchdelete=\"Delete the selected contacts?\"
mautic.lead.lead.form.confirmdelete=\"Delete this contact?\"
mautic.lead.lead.form.leadlists=\"filter by segment...\"
mautic.lead.lead.header.campaigns=\"Campaigns for %name%\"
mautic.lead.lead.header.contact.frequency=\"Contact Preference Center\"
mautic.lead.lead.header.edit=\"Edit %name%\"
mautic.lead.lead.header.ipaddress=\"IP Addresses\"
mautic.lead.lead.header.lists=\"Segments for %name%\"
mautic.lead.lead.header.new=\"New Contact\"
mautic.lead.lead.header.pointslog=\"Points Change Log\"
mautic.lead.lead.header.quick.add=\"Quick Add New Contact\"
mautic.lead.lead.header.socialprofiles=\"Social Profiles\"
mautic.lead.lead.header.merge=\"Merge %name%\"
mautic.lead.lead.import=\"Import\"
mautic.lead.lead.stage=\"Contact Stage\"
mautic.lead.import.list=\"Imports\"
mautic.lead.import.source.file=\"Source file\"
mautic.lead.lead.import.index=\"Import History\"
mautic.lead.import.failed.rows=\"Failed rows\"
mautic.lead.import.no.failed.rows=\"No failed rows found\"
mautic.lead.import.csv.line.number=\"CSV line number\"
mautic.lead.import.status=\"Status\"
mautic.lead.import.status.info=\"Status info\"
mautic.lead.import.status.1=\"Queued\"
mautic.lead.import.status.2=\"In Progress\"
mautic.lead.import.status.3=\"Imported\"
mautic.lead.import.status.4=\"Failed\"
mautic.lead.import.status.5=\"Stopped\"
mautic.lead.import.status.6=\"Manual\"
mautic.lead.import.status.7=\"Delayed\"
mautic.lead.import.stage.not.exists=\"\"Stage with ID or name '%id%' was not found.\"\"
mautic.lead.import.parallel.limit.hit=\"Import was delayed because the parallel import limit of %limit% has been hit.\"
mautic.lead.view.imports=\"View Imports\"
mautic.lead.import.queue.btn=\"Finish in the background\"
mautic.lead.import.speed=\"Import speed\"
mautic.lead.import.speed.value=\"%speed% rows/second\"
mautic.lead.import.line.count=\"Total rows\"
mautic.lead.import.inserted.count=\"Inserted\"
mautic.lead.import.updated.count=\"Updated\"
mautic.lead.import.ignored.count=\"Ignored\"
mautic.lead.import.progress=\"Progress\"
mautic.lead.import.runtime=\"Runtime\"
mautic.lead.import.date.started=\"Import started on\"
mautic.lead.import.date.ended=\"Import ended on\"
mautic.lead.import.contact.action.identified_contact=\"Contact identified on import\"
mautic.lead.import.contact.action.inserted=\"Contact imported from %name%\"
mautic.lead.import.contact.action.updated=\"Contact updated from %name%\"
mautic.lead.import.contact.action.failed=\"Contact import failed from %name%\"
mautic.lead.import.row.statuses=\"Import row statuses\"
mautic.lead.import.processed.rows.minute=\"Rows processed per minute\"
mautic.lead.import.processed.rows=\"Processed rows\"
mautic.lead.event.imported=\"Imported\"
mautic.lead.lead.lists=\"Segments\"
mautic.lead.lead.live_update=\"Enable live mode where new contacts are automatically injected to the top of the segment as they are created.\"
mautic.lead.lead.menu.index=\"Manage Contacts\"
mautic.lead.lead.menu.quickadd=\"Quick Add\"
mautic.lead.lead.pointscount=\"Contact points\"
mautic.lead.lead.pointsevent.created=\"Contact manually created\"
mautic.lead.lead.primary=\"Primary\"
mautic.lead.lead.remove.fromlist=\"Remove from segment\"
mautic.lead.lead.searchcommand.company=\"company\"
mautic.lead.lead.searchcommand.company_id=\"company_id\"
mautic.lead.lead.searchcommand.isanonymous=\"is:anonymous\"
mautic.lead.lead.searchcommand.isunowned=\"is:unowned\"
mautic.lead.lead.searchcommand.list=\"segment\"
mautic.lead.lead.searchcommand.owner=\"owner\"
mautic.lead.lead.searchcommand.stage=\"stage\"
mautic.lead.lead.searchcommand.tag=\"tag\"
mautic.lead.lead.searchcommand.duplicate=\"common\"
mautic.lead.lead.searchcommand.email_sent=\"email_sent\"
mautic.lead.lead.searchcommand.email_read=\"email_read\"
mautic.lead.lead.searchcommand.email_queued=\"email_queued\"
mautic.lead.lead.searchcommand.email_pending=\"email_pending\"
mautic.lead.lead.searchcommand.page_source=\"page_source\"
mautic.lead.lead.searchcommand.page_source_id=\"page_source_id\"
mautic.lead.lead.searchcommand.import_id=\"import_id\"
mautic.lead.lead.searchcommand.import_action=\"import_action\"
mautic.lead.lead.searchcommand.page_id=\"page_id\"
mautic.lead.lead.searchcommand.mobile_sent=\"mobile_sent\"
mautic.lead.lead.searchcommand.web_sent=\"web_sent\"
mautic.lead.lead.searchcommand.sms_sent=\"sms_sent\"
mautic.lead.lead.social.foursquare.lists=\"Segments\"
mautic.lead.lead.social.foursquare.mayorship=\"Mayorships\"
mautic.lead.lead.social.foursquare.tips=\"Tips\"
mautic.lead.lead.social.lastupdate=\"Last refreshed at %datetime%\"
mautic.lead.lead.social.photos=\"Photos\"
mautic.lead.lead.social.posts=\"Posts\"
mautic.lead.lead.social.profile=\"Profile\"
mautic.lead.lead.social.removecache=\"Remove this network's data for the contact.\"
mautic.lead.lead.social.tags=\"Tags\"
mautic.lead.lead.social.twitter.tweets=\"Tweets\"
mautic.lead.lead.submitaction=\"Contact actions\"
mautic.lead.lead.submitaction.changepoints=\"Adjust contact's points\"
mautic.lead.lead.submitaction.changepoints_descr=\"Change points based on form results.\"
mautic.lead.lead.submitaction.operator=\"Operator\"
mautic.lead.lead.submitaction.operator_divide=\"divide (/)\"
mautic.lead.lead.submitaction.operator_minus=\"subtract (-)\"
mautic.lead.lead.submitaction.operator_plus=\"add (+)\"
mautic.lead.lead.submitaction.operator_times=\"multiply (x)\"
mautic.lead.lead.submitaction.operator_set=\"set\"
mautic.lead.lead.submitaction.points=\"Amount to change points by\"
mautic.lead.lead.tab.history=\"History\"
mautic.lead.lead.tab.notes=\"Notes\"
mautic.lead.lead.tab.social=\"Social\"
mautic.lead.lead.tab.integration=\"Integrations\"
mautic.lead.lead.tab.auditlog=\"Audit log\"
mautic.lead.lead.tab.socialactivity=\"Public Activity\"
mautic.lead.lead.tab.socialprofile=\"Public Profile\"
mautic.lead.lead.tab.places=\"Places\"
mautic.lead.lead.thead.action=\"Triggering Action\"
mautic.lead.lead.thead.city=\"City\"
mautic.lead.lead.thead.country=\"Country\"
mautic.lead.lead.thead.delta=\"Points &Delta;\"
mautic.lead.lead.thead.event=\"Triggering Event\"
mautic.lead.lead.thead.location=\"Location\"
mautic.lead.lead.thead.state=\"State\"
mautic.lead.lead.timeline=\"Timeline\"
mautic.lead.lead.upcoming.event.triggered.at=\"<strong class='text-primary'>%event%</strong> event will be triggered at %link%\"
mautic.lead.lead.upcoming.events=\"Upcoming Events\"
mautic.keyboard.section.contacts=\"Contacts\"
mautic.lead.leads=\"Contacts\"
mautic.lead.lifecycle.graph.device.granularity=\"Devices\"
mautic.lead.lifecycle.graph.pie.all.lists=\"All Contacts\"
mautic.lead.lifecycle.graph.stage.cycle=\"Stage cycle\"
mautic.lead.list.rebuild.total.time=\"Total time: %time% seconds\"
mautic.lead.list.rebuild.contacts.time=\"Rebuilding contacts time: %time% seconds\"
mautic.lead.list.rebuild.leads_affected=\"%leads% contact(s) affected\"
mautic.lead.list.rebuild.rebuilding=\"Rebuilding contacts for segment %id%\"
mautic.lead.list.rebuild.not_found=\"Segment #%id% does not exist\"
mautic.lead.list.rebuild.to_be_added=\"%leads% total contact(s) to be added in batches of %batch%\"
mautic.lead.list.rebuild.to_be_removed=\"%leads% total contact(s) to be removed in batches of %batch%\"
mautic.lead.list.filter.date_identified=\"Date Identified\"
mautic.lead.list.filter.dnc_bounced=\"Bounced - Email\"
mautic.lead.list.filter.dnc_unsubscribed=\"Unsubscribed - Email\"
mautic.lead.list.filter.dnc_manual_email=\"Unsubscribed Manual - Email\"
mautic.lead.list.filter.dnc_manual_sms = \"Unsubscribed Manual - SMS\"
mautic.lead.list.filter.last_active=\"Date Last Active\"
mautic.lead.list.filter.campaign=\"Campaign Membership\"
mautic.lead.list.filter.date_modified=\"Modified Date\"
mautic.lead.list.filter.lists=\"Segment Membership\"
mautic.lead.list.filter.lead_asset_download=\"Downloaded a specific asset\"
mautic.lead.list.filter.lead_email_received=\"Read a specific email\"
mautic.lead.list.filter.lead_email_sent=\"Was sent a specific email\"
mautic.lead.list.filter.lead_email_sent_date=\"Sent any email (date)\"
mautic.lead.list.filter.lead_email_read_date=\"Read any email (date)\"
mautic.lead.list.filter.lead_email_read_count=\"Read any email X number of times\"
mautic.lead.list.filter.visited_url=\"Visited X URL\"
mautic.lead.list.filter.visited_url_count=\"Visited any URL X number of times \"
mautic.lead.list.filter.url_title=\"Visited any URL with X page title\"
mautic.lead.list.filter.source=\"Visited any URL from X source\"
mautic.lead.list.filter.source.id=\"Visited any URL from X source ID \"
mautic.lead.list.filter.session=\"Has X number of browsing sessions\"
mautic.lead.list.filter.page_id=\"Visited a specific landing page\"
mautic.lead.list.filter.placeholder=\"Segment Category Filter\"
mautic.lead.list.filter.referer=\"Visited any URL from X referrer\"
mautic.lead.list.filter.visited_url_date=\"Visited any URL (date)\"
mautic.lead.list.source.segment.category=\"Segment Category\"
mautic.lead.list.filter.notification=\"Has been sent any push notification\"
mautic.lead.list.filter.owner=\"Owner\"
mautic.lead.list.filter.tags=\"Tags\"
mautic.lead.list.filter.device_type=\"Device Type\"
mautic.lead.list.filter.device_brand=\"Device Brand\"
mautic.lead.list.filter.device_os=\"Device OS\"
mautic.lead.list.filter.device_model=\"Device Model\"
mautic.lead.list.filter.redirect_id=\"Clicked any link from any channel\"
mautic.lead.list.filter.email_id=\"Clicked any link from any email\"
mautic.lead.list.filter.email_clicked_link_date=\"Clicked any link from any email (date)\"
mautic.lead.list.filter.sms_clicked_link=\"Clicked any link from any text message\"
mautic.lead.list.filter.sms_clicked_link_date=\"Clicked any link from any text message (date)\"
mautic.lead.list.form.config.segment_rebuild_time.message=\"This segment hasn't been rebuilt for 1 hour.|This segment hasn't been rebuilt for %count% hours.\"
mautic.lead.list.form.config.segment_rebuild_time_warning=\"Show warning if segment hasn't been rebuilt for X hours\"
mautic.lead.list.form.config.segment_rebuild_time_warning.tooltip=\"A red exclamation sign will be displayed next to a segment name\"
mautic.lead.list.form.config.segment_build_time.message=\"This segment build time is %count% seconds.\"
mautic.lead.list.form.config.segment_build_time_warning=\"Show warning if segment build time is longer than X seconds\"
mautic.lead.list.form.config.segment_build_time_warning.tooltip=\"A red clock icon will be displayed next to a segment name\"
mautic.lead.list.form.confirmbatchdelete=\"Delete the selected segments?\"
mautic.lead.list.form.confirmdelete=\"Delete the segment, %name%?\"
mautic.lead.list.form.filters.add=\"Add Filter\"
mautic.lead.list.form.filtervalue=\"filter value\"
mautic.lead.list.form.glue.and=\"and\"
mautic.lead.list.form.glue.or=\"or\"
mautic.lead.list.form.isglobal=\"Visible to other users\"
mautic.lead.list.form.isglobal.tooltip=\"Only users within Mautic will be able to see this segment. When disabled, this segment is only available to you.\"
mautic.lead.list.form.isglobal.no=\"Only me\"
mautic.lead.list.form.publicname=\"Public name\"
mautic.lead.list.form.publicname.tooltip=\"Name visible in Preference Center\"
mautic.lead.list.form.isPreferenceCenter=\"Available in Preference Center\"
mautic.lead.list.form.isPreferenceCenter.tooltip=\"Segment can be editable by contact in preferences center.\"
mautic.lead.list.form.operator.between=\"between\"
mautic.lead.list.form.operator.equals=\"equals\"
mautic.lead.list.form.operator.greaterthan=\"greater than\"
mautic.lead.list.form.operator.greaterthanequals=\"greater than or equal\"
mautic.lead.list.form.operator.in=\"including\"
mautic.lead.list.form.operator.isempty=\"empty\"
mautic.lead.list.form.operator.islike=\"like\"
mautic.lead.list.form.operator.isnotempty=\"not empty\"
mautic.lead.list.form.operator.regexp=\"regexp\"
mautic.lead.list.form.operator.notregexp=\"not regexp\"
mautic.lead.list.form.operator.isnotlike=\"not like\"
mautic.lead.list.form.operator.lessthan=\"less than\"
mautic.lead.list.form.operator.lessthanequals=\"less than or equal\"
mautic.lead.list.form.operator.notbetween=\"not between\"
mautic.lead.list.form.operator.notequals=\"not equal\"
mautic.lead.list.form.operator.notin=\"excluding\"
mautic.lead.list.form.startTyping=\"start typing\"
mautic.lead.list.frequency.number=\"Do not contact more than\"
mautic.lead.list.form.operator.date=\"date\"
mautic.lead.list.frequency.rules.msg=\"Frequency Rules have changed\"
mautic.lead.list.frequency.times=\"messages each\"
mautic.lead.list.header.edit=\"Edit Segment - %name%\"
mautic.lead.list.header.index=\"Contact Segments\"
mautic.lead.list.header.new=\"New Segment\"
mautic.lead.list.help.alias=\"Letters and numbers (with no spaces) used to identify this segment\"
mautic.lead.list.menu.index=\"Segments\"
mautic.lead.list.searchcommand.isglobal=\"is:global\"
mautic.lead.list.thead.leadcount=\"# contacts\"
mautic.lead.list.view=\"View %objects%\"
mautic.lead.list.view_contacts=\"View Contacts\"
mautic.lead.list.view_companies=\"View Companies\"
mautic.lead.list.viewleads_count=\"{0} No Contacts|{1} View 1 Contact|]1,Inf[ View %count% Contacts\"
mautic.lead.list.month_last=\"last month\"
mautic.lead.list.month_next=\"next month\"
mautic.plugin.actions.tooltip=\"Push a contact to the selected integration.\"
mautic.lead.list.month_this=\"this month\"
mautic.lead.list.today=\"today\"
mautic.lead.list.tomorrow=\"tomorrow\"
mautic.lead.list.yesterday=\"yesterday\"
mautic.lead.list.week_last=\"last week\"
mautic.lead.list.week_next=\"next week\"
mautic.lead.list.week_this=\"this week\"
mautic.lead.list.year_last=\"last year\"
mautic.lead.list.year_next=\"next year\"
mautic.lead.list.year_this=\"this year\"
mautic.lead.list.anniversary=\"anniversary\"
mautic.lead.list.checkall.help=\"If you select multiple contacts at once, a green drop-down arrow will appear at the top of the list. You can manage bulk actions from this drop-down list (ex. Change segments or Set Do Not Contact).\"
mautic.lead.list.copy.filter.group=\"The entire filter block will be duplicated\"
mautic.lead.merge=\"Merge\"
mautic.lead.merge.count=\"%count% contacts were merged.\"
mautic.lead.merge.select=\"Choose the contact to merge with:\"
mautic.lead.merge.select.tooltip=\"Choose the contact to merge with.\"
mautic.lead.merge.select.modal.tooltip=\"Filter the options using the search field, then select the lead to merge.\"
mautic.lead.note.confirmdelete=\"Delete this note?\"
mautic.lead.note.details=\"At %dateAdded%, %author% wrote:\"
mautic.lead.note.event=\"Note at %lead%\"
mautic.lead.note.form.text=\"Note text\"
mautic.lead.note.form.type=\"Note Type\"
mautic.lead.note.header.edit=\"Edit note\"
mautic.lead.note.header.new=\"New note\"
mautic.lead.note.notes=\"Contact Notes\"
mautic.lead.note.searchcommand.call=\"call\"
mautic.lead.note.searchcommand.email=\"email\"
mautic.lead.note.searchcommand.general=\"general\"
mautic.lead.note.searchcommand.meeting=\"meeting\"
mautic.lead.note.searchcommand.type=\"type\"
mautic.lead.note.type.call=\"Call\"
mautic.lead.note.type.email=\"Email\"
mautic.lead.note.type.general=\"General\"
mautic.lead.note.type.meeting=\"Meeting\"
mautic.lead.permissions.fields=\"Custom Fields - User has access to\"
mautic.lead.permissions.header=\"Contact Permissions\"
mautic.lead.permissions.leads=\"Contacts - User has access to\"
mautic.lead.permissions.lists=\"Segments - User has access to\"
mautic.lead.permissions.imports=\"Import - User has access to\"
mautic.lead.point.trigger=\"Contact triggers\"
mautic.lead.point.trigger.changelists=\"Modify contact's segments\"
mautic.lead.points=\"Points\"
mautic.lead.points.count=\"{0}0 points|{1}1 point|]1,Inf[%count% points|{-1}-1 point|]-Inf,-1[%count% points\"
mautic.lead.groups.panel.title=\"Group points\"
mautic.lead.remove_dnc_status=\"Re-enable contact\"
mautic.lead.report.attribution.multi=\"Multi Touch Attributions\"
mautic.lead.report.attribution.first=\"First Touch Attributions\"
mautic.lead.report.attribution.last=\"Last Touch Attributions\"
mautic.lead.report.attribution.campaign_id=\"Campaign ID\"
mautic.lead.report.attribution.campaign_name=\"Campaign Name\"
mautic.lead.report.attribution.channel=\"Channel\"
mautic.lead.report.attribution.channel_action=\"Channel Action Type\"
mautic.lead.report.attribution.action_name=\"Channel Action Name\"
mautic.lead.report.attribution.action_date=\"Channel Action Date\"
mautic.lead.report.attribution.filter.stage=\"Contact Stage\"
mautic.lead.report.attribution.filter.campaign=\"Campaign\"
mautic.lead.report.attribution.stage_id=\"Stage ID\"
mautic.lead.report.attribution.stage_name=\"Stage Name\"
mautic.lead.report.attribution.stage_date_added=\"Stage Date Added\"
mautic.lead.report.contact_id=\"Contact ID\"
mautic.lead.report.field.lead.label=\"Contact %field%\"
mautic.lead.report.date_identified=\"Date identified\"
mautic.lead.report.owner_firstname=\"Owner first name\"
mautic.lead.report.owner_id=\"Owner ID\"
mautic.lead.report.owner_lastname=\"Owner last name\"
mautic.lead.report.points.action_name=\"Point event action\"
mautic.lead.report.points.date_added=\"Point change date\"
mautic.lead.report.points.delta=\"Point change\"
mautic.lead.report.points.event_name=\"Point event name\"
mautic.lead.report.points.table=\"Contact Point Log\"
mautic.lead.report.points.type=\"Point event type\"
mautic.lead.report.points.id=\"Point ID\"
mautic.lead.report.points.group_id=\"Group ID\"
mautic.lead.report.points.group_name=\"Group name\"
mautic.lead.report.segment.id=\"Segment ID\"
mautic.lead.report.segment.membership=\"Segment Membership\"
mautic.lead.report.segment.log=\"Contact's segments activity log\"
mautic.lead.report.segment.manually_added=\"Manually added\"
mautic.lead.report.segment.manually_removed=\"Manually removed\"
mautic.lead.report.segment.date_added=\"Date added to segment\"
mautic.lead.report.segment.date_removed=\"Date removed from segment\"
mautic.lead.report.utm.utm_tag=\"UTM codes\"
mautic.lead.report.utm.campaign=\"UTM campaign\"
mautic.lead.report.utm.content=\"UTM content\"
mautic.lead.report.utm.medium=\"UTM medium\"
mautic.lead.report.utm.source=\"UTM source\"
mautic.lead.report.utm.term=\"UTM term\"
mautic.lead.report.dnc=\"Do Not Contact\"
mautic.lead.report.dnc_comment=\"DNC Comment\"
mautic.lead.report.dnc_contactable=\"Contactable\"
mautic.lead.report.dnc_unsubscribed=\"DNC Unsubscribed\"
mautic.lead.report.dnc_bounced=\"DNC Bounced\"
mautic.lead.report.dnc_manual=\"DNC Manually Unsubscribed\"
mautic.lead.report.dnc_reason=\"DNC Reason\"
mautic.lead.report.dnc_channel=\"DNC Channel\"
mautic.lead.report.dnc_channel_id=\"DNC Channel ID\"
mautic.lead.report.dnc_date_added=\"DNC Date\"
mautic.lead.report.devices=\"Devices\"
mautic.lead.report.dev_date_added=\"Device date added\"
mautic.lead.report.dev_client_info=\"Device client info\"
mautic.lead.report.dev_device=\"Device type\"
mautic.lead.report.dev_device_os_name=\"Device OS name\"
mautic.lead.report.dev_device_os_version=\"Device OS version\"
mautic.lead.report.dev_device_os_platform=\"Device OS platform \"
mautic.lead.report.dev_device_brand=\"Device brand\"
mautic.lead.report.dev_device_model=\"Device model\"
mautic.lead.integrations.header=\"No integration relationships found. They will be displayed automatically here when users are modified by plugins.\"
mautic.lead.socialprofiles.header=\"We’re still on the lookout. Remember to set up your social networks in the Integration Manager.\"
mautic.lead.auditlog.header=\"No audit log entries found\"
mautic.lead.socialprofiles.noresults=\"Search again\"
mautic.lead.stage=\"On stage: %stage%\"
mautic.lead.stage.label=\"Stage\"
mautic.lead.table.most.points=\"Contacts with most points\"
mautic.lead.table.top.actions=\"Top Actions\"
mautic.lead.table.top.cities=\"Top Cities\"
mautic.lead.table.top.countries=\"Top Countries\"
mautic.lead.table.top.events=\"Top Events\"
mautic.lead.tags=\"Tags\"
mautic.lead.tags.add=\"Add tags\"
mautic.lead.tags.enter_to_create=\"Hit enter to create \"
mautic.lead.tags.remove=\"Remove tags\"
mautic.lead.tags.select_or_create=\"Select or type in a new tag\"
mautic.lead.timeline.campaign_membership=\"Campaign membership change\"
mautic.lead.timeline.campaign_membership_added_by_object=\"Contact added to campaign, %name%\"
mautic.lead.timeline.campaign_membership_removed_by_object=\"Contact removed from campaign, %name%\"
mautic.lead.timeline.created_source=\"Contact created by source\"
mautic.lead.timeline.displaying_events=\"Displaying %total% events\"
mautic.lead.timeline.events_new=\"new\"
mautic.lead.timeline.user_name=\"User/Source Name\"
mautic.lead.timeline.event_name=\"Event Name\"
mautic.lead.timeline.event_type=\"Event Type\"
mautic.lead.timeline.event_timestamp=\"Event Timestamp\"
mautic.lead.timeline.event.utmcampaign=\"UTM Campaign\"
mautic.lead.timeline.event.utmcontent=\"UTM Content\"
mautic.lead.timeline.event.utmmedium=\"UTM Medium\"
mautic.lead.timeline.event.umtsource=\"UTM Source\"
mautic.lead.timeline.event.utmtags=\"UTM Tags\"
mautic.lead.timeline.event.utmterm=\"UTM Term\"
mautic.lead.timeline.identified_source=\"Contact identified by source\"
mautic.lead.timeline.lead.source.created=\"Contact was created by an unknown source (%bundle%/%object%)\"
mautic.lead.timeline.lead.source.created_by_object=\"Contact was created by %name%\"
mautic.lead.timeline.lead.source.identified=\"Contact was identified by an unknown source (%bundle%/%object%)\"
mautic.lead.timeline.lead.source.identified_by_object=\"Contact was identified by %name%\"
mautic.lead.timeline.segment_membership=\"Segment membership change\"
mautic.lead.timeline.segment_membership_added_by_object=\"Contact added to segment, %name%\"
mautic.lead.timeline.segment_membership_removed_by_object=\"Contact removed from segment, %name%\"
mautic.lead.timeline.toggle_all_details=\"Toggle all event details.\"
mautic.lead.timeline.toggle_details=\"Toggle details.\"
mautic.lead.tooltip.grid=\"Grid view\"
mautic.lead.dashboard.widgets=\"Contact Widgets\"
mautic.widget.created.leads.in.time=\"Created contacts in time\"
mautic.widget.device.granularity=\"Device granularity\"
mautic.widget.anonymous.vs.identified.leads=\"Anonymous vs identified contacts\"
mautic.widget.map.of.leads=\"Map\"
mautic.widget.lead.lifetime=\"Lifecycle\"
mautic.lead.list.filter=\"Segment Filter\"
mautic.widget.top.lists=\"Top segments\"
mautic.lead.show.all=\"Show all contacts\"
mautic.lead.show.top=\"Top segments\"
mautic.lead.show.identified.vs.anonymous=\"All Identified vs Anonymous\"
mautic.lead.show.top.leads.identified.vs.anonymous=\"Top Segments with Identified vs Anonymous\"
mautic.widget.top.owners=\"Top contact owners\"
mautic.widget.top.creators=\"Top contact creators\"
mautic.widget.segments.build.time=\"Segments build time\"
mautic.widget.segments.build.time.longest=\"Longest time\"
mautic.widget.segments.build.time.shortest=\"Shortest time\"
mautic.widget.created.leads=\"Created contacts\"
mautic.lead.show.identified=\"Only identified\"
mautic.lead.show.anonymous=\"Only anonymous\"
mautic.lead.all.leads=\"All contacts\"
mautic.lead.identified=\"Identified\"
mautic.lead.tooltip.list=\"List view\"
mautic.lead.webhook.event.lead.deleted=\"Contact Deleted Event\"
mautic.lead.webhook.event.lead.deleted_desc=\"Triggered when a contact is deleted.\"
mautic.lead.webhook.event.lead.new=\"Contact Identified Event\"
mautic.lead.webhook.event.lead.new_desc=\"Triggered when a contact is identified.\"
mautic.lead.webhook.event.lead.points=\"Contact Points Changed Event\"
mautic.lead.webhook.event.lead.points_desc=\"Triggered when a contact's points are modified.\"
mautic.lead.webhook.event.lead.update=\"Contact Updated Event\"
mautic.lead.webhook.event.lead.update_desc=\"Triggered when a contact is updated.\"
mautic.lead.webhook.event.lead.dnc=\"Contact Channel Subscription Change Event\"
mautic.lead.webhook.event.lead.dnc_desc=\"Triggered when a contact's channel subscription status changes.\"
mautic.lead.webhook.event.lead.company.change=\"Contact Company Subscription Change Event\"
mautic.lead.webhook.event.lead.company.change.desc=\"Triggered when a company is added or removed to/from contact\"
mautic.lead.webhook.event.company.new_or_update=\"Company Create/Update Event\"
mautic.lead.webhook.event.company.new_or_update_desc=\"Triggered when a company is created/updated\"
mautic.lead.webhook.event.company.deleted=\"Company Deleted Event\"
mautic.lead.webhook.event.company.deleted_desc=\"Triggered when a company is deleted\"
mautic.lead.webhook.event.lead.segment.change=\"Contact Segment Membership Change Event\"
mautic.lead.webhook.event.lead.segment.change.desc=\"Triggered when a contact segment membership is changed\"
mautic.lead.campaign.event.field=\"Contact Field\"
mautic.lead.campaign.event.field_descr=\"Select the contact field which holds the value you want to compare.\"
mautic.lead.campaign.event.device_type=\"Device type\"
mautic.lead.campaign.event.device_brand=\"Device brand\"
mautic.lead.campaign.event.device_os=\"Device OS\"
mautic.lead.campaign.event.point_operator=\"Operator\"
mautic.lead.campaign.event.point_score=\"Score\"
mautic.lead.campaign.event.point_group=\"Point group\"
mautic.lead.campaign.event.point_group.help=\"Leave empty to use main score\"
mautic.maintenance.visitors=\"Visitors\"
mautic.report.group.contacts=\"Contacts\"
mautic.report.field.company.label=\"Company %field%\"
mautic.lead.exists.by.field=\"A contact with this value already exists\"
mautic.lead.field.object=\"Object\"
mautic.companies.menu.index=\"Companies\"
mautic.companies.menu.root=\"Companies\"
mautic.company.action.noresults.tip=\"Create a company to group contacts that belong to a same company. It will also help you keep important information about different companies you target.\"
mautic.company.menu.new=\"New Company\"
mautic.company.menu.edit=\"Edit Company %name%\"
mautic.company.name=\"Company name\"
mautic.company.company.number=\"Company number\"
mautic.company.company.source=\"Company source\"
mautic.company.annual.revenue=\"Annual revenue\"
mautic.company.email=\"Company email\"
mautic.company.website=\"Company website\"
mautic.company.phone=\"Company phone\"
mautic.company.fax=\"Company fax\"
mautic.company.numberOfEmployees=\"Number of employees\"
mautic.company.score=\"Score\"
mautic.company.score.count=\"{0}0 score|{1}1 score|]1,Inf[%count% score|{-1}-1 point|]-Inf,-1[%count% score\"
mautic.company.address1=\"Address line 1\"
mautic.company.address2=\"Address line 2\"
mautic.company.city=\"City\"
mautic.company.state=\"State\"
mautic.company.country=\"Country\"
mautic.company.zipcode = \"Zip Code\"
mautic.company.company=\"Company\"
mautic.lead.company.viewleads_count=\"view contacts %count%\"
mautic.lead.lead.companies=\"Companies\"
mautic.lead.lead.segment.add.help=\"If you upload a CSV contact file to a segment, it will become a static list. Applying additional filters to this segment will not remove any contacts from that uploaded list.\"
mautic.lead.lead.segment.filter.info=\"Contacts that match the filters will be added, and contacts that no longer match will be removed. Those manually added will remain untouched.\"
mautic.lead.lead=\"Contact\"
mautic.lead.company=\"Primary company\"
mautic.lead.lead.header.companies=\"Add contact to companies\"
mautic.lead.lead.events.addtocompany=\"Add to company action\"
mautic.lead.lead.events.addtocompany_descr=\"This action will add contacts to the selected company\"
mautic.lead.lead.events.changeowner=\"Update contact owner\"
mautic.lead.lead.events.changeowner_descr=\"This action will update contact owner as part of a campaign\"
mautic.company.selectcompany=\"Select a company\"
mautic.company.selectcompany_descr=\"Contacts targeted in this campaign will be added to the selected company\"
mautic.company.new.company=\"New Company\"
mautic.company.field.address=\"Company Address\"
mautic.company.form.confirmdelete=\"Delete this company?\"
mautic.company.form.confirmbatchdelete=\"Delete these companies?\"
mautic.lead.field.companyemail=\"Company Email\"
mautic.lead.field.companyname=\"Company Name\"
mautic.lead.field.companyaddress1=\"Address 1\"
mautic.lead.field.companyaddress2=\"Address 2\"
mautic.lead.field.companycity=\"City\"
mautic.lead.field.companystate=\"State\"
mautic.lead.field.companycountry=\"Country\"
mautic.lead.field.companyzipcode=\"Zip Code\"
mautic.lead.field.companyindustry=\"Industry\"
mautic.lead.field.companyphone=\"Phone\"
mautic.lead.field.companydescription=\"Description\"
mautic.lead.field.companywebsite=\"Website\"
mautic.lead.field.companynumber_of_employees=\"Number of Employees\"
mautic.lead.field.companyfax=\"Fax\"
mautic.lead.field.companyannual_revenue=\"Annual Revenue\"
mautic.lead.company.field.owner=\"Company Owner\"
mautic.lead.preferred.channels=\"Preferred\"
mautic.lead.preferred.categories=\"Categories\"
mautic.lead.preferred.segments=\"Segments\"
mautic.lead.preferred.campaigns=\"Campaigns\"
mautic.lead.list.frequency.preferred.channel=\"I prefer communication by\"
mautic.lead.list.last_built_time=\"Last built time\"
mautic.lead.form.list=\"My segments\"
mautic.lead.frequency.contact.start.date=\"From\"
mautic.lead.frequency.contact.end.date=\"to\"
mautic.lead.frequency.dates.label=\"Pause from\"
mautic.lead.contact.me.label=\"I want to receive %channel%\"
mautic.lead.form.categories=\"My categories\"
mautic.lead.preferred.frequency=\"Frequency\"
mautic.lead.company.set.primary=\"Click to (un)set as primary\"
mautic.lead.graph.line.companies=\"Companies in time\"
mautic.lead.all.companies=\"All companies\"
mautic.lead.graph.pie.companies.industry=\"Companies by Industry\"
mautic.lead.table.pie.company.country=\"Companies by Country\"
mautic.lead.company.table.top.cities=\"Companies by City\"
mautic.report.group.companies=\"Companies\"
mautic.lead.report.company.company_id=\"Company ID\"
mautic.lead.report.company.is_primary=\"Is the primary company\"
mautic.lead.report.company.date_added=\"Date added to company\"
mautic.lead.company.header.merge=\"Merging current company\"
mautic.company.to.merge.into=\"Choose a company to merge into\"
mautic.lead.lead.events.changecompanyscore=\"Add to company's score\"
mautic.lead.lead.events.changecompanyscore_descr=\"This action will add the specified value to the company's existing score\"
mautic.lead.timeline.displaying_events_for_contact=\"for contact: %contact% (%id%)\"
mautic.lead.list.filter.categories=\"Subscribed Categories\"
mautic.lead.list.filter.utmcampaign=\"UTM Campaign\"
mautic.lead.list.filter.utmcontent=\"UTM Content\"
mautic.lead.list.filter.utmmedium=\"UTM Medium\"
mautic.lead.list.filter.utmsource=\"UTM Source\"
mautic.lead.list.filter.utmterm=\"UTM Term\"
mautic.lead.audit.created=\"The contact was created.\"
mautic.lead.audit.deleted=\"The contact was deleted.\"
mautic.lead.audit.updated=\"The contact was updated.\"
mautic.lead.audit.identified=\"The contact was identified.\"
mautic.lead.audit.merged=\"The contact was merged.\"
mautic.lead.audit.originip=\"Origin IP:\"
mautic.lead.audit.accessed=\"The contact was accessed from: \"
mautic.lead.audit.log.field=\"Field/Object\"
mautic.lead.audit.log.new_value=\"New Value\"
mautic.lead.audit.log.old_value=\"Old Value\"
mautic.lead.report.frequency.messages=\"Frequency Rules\"
mautic.lead.report.frequency.frequency_number=\"Frequency\"
mautic.lead.report.frequency.frequency_time=\"Frequency time\"
mautic.lead.report.frequency.channel=\"Frequency channel\"
mautic.lead.report.frequency.preferred_channel=\"Preferred channel\"
mautic.lead.report.frequency.pause_from_date=\"Pause from\"
mautic.lead.report.frequency.pause_to_date=\"Pause to\"
mautic.lead.report.frequency.date_added=\"Frequency rule added date\"
mautic.segment.contact.manually.added=\"Manually added contacts\"
mautic.segment.contact.manually.removed=\"Manually removed contacts\"
mautic.segment.contact.filter.added=\"Filter added contacts\"
mautic.segment.segment=\"Segment\"
mautic.segment.stats=\"Contacts in time\"
mautic.segment.form.confirmdelete=\"Delete the segment, %name%?\"
mautic.lead.segments.contacts=\"All contacts\"
mautic.lead.segments.contacts.added=\"Added\"
mautic.lead.segments.contacts.removed=\"Removed\"
mautic.lead.segments.contacts.total=\"Total\"
mautic.channel.stat.leadcount.tooltip=\"Details may not match summary numbers if the contact no longer exists in Mautic or if a contact was sent the message multiple times\"
mautic.lead.segments.usages=\"Segment usages\"
mautic.lead.segments.no_usages=\"Looks like this segment is not in use.\"
mautic.lead.campaign.share=\"Campaign share\"
mautic.lead.share=\"Share\"
mautic.lead.field.notfound=\"Lead Field was not found\"
mautic.lead.field.column_was_created=\"Column with ID %id% was created\"
mautic.lead.field.column_already_created=\"Column was already created\"
mautic.lead.field.column_creation_aborted=\"Column creation was aborted\"
mautic.lead.field.column_update_aborted=\"Column update was aborted\"
mautic.lead.field.column_was_updated=\"Column was updated\"
mautic.lead.field.max_column_error=\"You have reached the limit of custom fields allowed by your database.\"
mautic.lead.field.pushed_to_background=\"Your custom field is being created, we will notify you when complete\"
mautic.lead.field.update_pushed_to_background=\"Your custom field is being updated, we will notify you when complete\"
mautic.lead.field.being_created_in_background=\"Custom field is being created in background\"
mautic.lead.field.notification.created_message=\"Your custom field '%label%' was created\"
mautic.lead.field.notification.created_header=\"Custom field created\"
mautic.lead.field.notification.updated_message=\"Your custom field '%label%' was updated\"
mautic.lead.field.notification.updated_header=\"Custom field updated\"
mautic.lead.field.notification.cannot_be_created_message=\"Custom field '%label%' cannot be created\"
mautic.lead.field.notification.cannot_be_created_header=\"Custom field cannot be created\"
mautic.lead.field.notification.custom_field_limit_hit_message=\"Custom field '%label%' cannot be created - you have reached the limit of custom fields allowed by your database.\"
mautic.lead.field.notification.custom_field_limit_hit_header=\"Custom field cannot be created\"
mautic.lead.command.error=\"Command %name%, error: %error%\"
mautic.lead.command.delete_contact_secondary_company.allow_multiple_enabled=\"The 'Multiple companies for contact' setting is enabled, aborting process. (Set this configuration option to false to run this command)\"
mautic.lead.command.delete_contact_secondary_company.success=\"Secondary companies have been successfully deleted.\"
mautic.lead.stats=\"Statistics\"
mautic.lead.stats.email_title=\"Channel: Email\"
mautic.lead.stats.sent_count=\"Total sent:\"
mautic.lead.stats.open_rate=\"Open rate:\"
mautic.lead.stats.click_through_rate=\"Click-through rate:\"
mautic.lead.stats.click_through_open_rate=\"Click-to-open rate:\"
mautic.lead.export.being.prepared.header=\"File is queued for processing\"
mautic.lead.export.being.prepared=\"The file will be sent to your email address '%user_email%' You can download the file from the link provided in the email.\"
mautic.lead.export.email_subject=\"Contacts export: %file_name%\"
mautic.lead.export.email=\"Your requested Contacts export: <a href=\"%link%\">%label%</a>.\"
mautic.lead.field.analyse.header.name=\"Custom Field Name\"
mautic.lead.field.analyse.header.alias=\"Custom Field Alias\"
mautic.lead.field.analyse.header.length=\"Current Size\"
mautic.lead.field.analyse.header.max_length=\"Currently Utilised max size\"
mautic.lead.field.analyse.header.suggested_length=\"Suggested max size\"
mautic.lead.field.analyse.header.indexed=\"Is Index Present\"
mautic.lead_list.filter.alert.regexp = 'This Regexp filter will slow down instance performance. We recommend using \"Starts with\" if possible.'
mautic.lead_list.filter.alert.endwith = 'This Ends With filter will slow down instance performance. We recommend using \"Starts with\" if possible.'
mautic.lead_list.filter.alert.contain = 'This Contains filter will slow down instance performance. We recommend using \"Starts with\" if possible.'
mautic.lead_list.filter.alert.like = 'This Like filter will slow down instance performance. We recommend using \"Starts with\" if possible.'
mautic.lead_list.filter.alert.email = 'Consider using the \"Email Domain\" filter instead of \"Email\" to be able to match the email domain.'
mautic.lead_list.filter.label.removefilter=\"Remove filter\"
mautic.lead_list.filter.label.clonefilter=\"Clone filter\"";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/LeadBundle/Translations/en_US/messages.ini";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/LeadBundle/Translations/en_US/messages.ini", "/var/www/html/mauticGIT-Test/app/bundles/LeadBundle/Translations/en_US/messages.ini");
    }
}
